==> open-xchange-guard_2.4.0.orig.tar.bz2: open-xchange-guard-2.4.0/com.openexchange.guard/src/com/openexchange/guard/servlets/AbstractGuardServlet.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.servlets;

import java.io.IOException;
import java.util.HashMap;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import com.openexchange.exception.OXException;
import com.openexchange.guard.common.servlets.utils.ServletUtils;
import com.openexchange.guard.logging.GuardLogProperties;
import com.openexchange.guard.oxapi.exceptions.OXApiException;

/**
 * Represents a OX Guard Servlet
 *
 * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
 * @since v2.4.0
 */
public abstract class AbstractGuardServlet extends HttpServlet {

    private static final long serialVersionUID = 8327090398980830760L;
    private static final Logger LOG = LoggerFactory.getLogger(AbstractGuardServlet.class);
    private static final String ACTION = "action";

    /**
     * Performs the an action requested by the "action" parameter in the given request if the action is an allowed action
     *
     * @param request the request containing the action parameter
     * @param response the response
     * @param allowedActions a set of allowed actions to perform
     */
    protected void doAction(HttpServletRequest request, HttpServletResponse response, HashMap<String, GuardServletAction> allowedActions) {
        String actionName = ServletUtils.getStringParameter(request, ACTION);
        GuardServletAction action = null;
        if (allowedActions != null && actionName != null) {
            action = allowedActions.get(actionName);
        }

        if (action != null) {
            doAction(request, response, actionName, action);
        } else {
            ServletUtils.sendError(response, "unknown action");
        }
    }

    /**
     * Performs the given action
     *
     * @param request request object
     * @param response response object
     * @param action the action to perform
     */
    protected void doAction(HttpServletRequest request, HttpServletResponse response, String actionName, GuardServletAction action) {
        try {
            action.doAction(request, response);
        } catch (OXApiException e) {
            //Passing the middleware exception on to the client
            LOG.error(String.format("OX API Error while processing command \"%s\": %s", actionName, e.getError()), e);
            ServletUtils.sendOK(response, e.getContentTypeHader().getValue(), e.getBackendErrorData());
        } catch (OXException e) {
            //Creating error object for the client
            LOG.error(String.format("Error processing command \"%s\": %s", actionName, e.getMessage()), e);
            try {
                new GuardErrorResponseRenderer().renderError(request, response, actionName, e);
            } catch (IOException e1) {
                LOG.error(String.format("Error writing response: %s", e.getMessage()), e1);
                ServletUtils.sendError(response, e.getMessage());
            }
        } catch (Exception e) {
            //Unexpected exception
            LOG.error(String.format("Error processing command \"%s\": %s", actionName, e.getMessage()), e);
            ServletUtils.sendError(response, e.getMessage());
        } finally {
            GuardLogProperties.removeLogProperties();
        }
    }
}

==> open-xchange-guard_2.6.0.orig.tar.bz2: open-xchange-guard-2.6.0/com.openexchange.guard/src/com/openexchange/guard/servlets/AbstractGuardServlet.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.servlets;

import java.io.IOException;
import java.util.HashMap;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import com.openexchange.exception.OXException;
import com.openexchange.guard.common.servlets.utils.ServletUtils;
import com.openexchange.guard.logging.GuardLogProperties;
import com.openexchange.guard.oxapi.exceptions.OXApiException;

/**
 * Represents a OX Guard Servlet
 *
 * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
 * @since v2.4.0
 */
public abstract class AbstractGuardServlet extends HttpServlet {

    private static final long serialVersionUID = 8327090398980830760L;
    private static final Logger LOG = LoggerFactory.getLogger(AbstractGuardServlet.class);
    private static final String ACTION = "action";
    private final GuardErrorResponseRenderer errorResponseRenderer;

    /**
     * Initializes a new {@link AbstractGuardServlet}.
     */
    public AbstractGuardServlet() {
        //Default OXException errors will be sent as SC_OK according to the OX HTTP API 
        errorResponseRenderer = new GuardErrorResponseRenderer(HttpServletResponse.SC_OK);
    }

    /**
     * Initializes a new {@link AbstractGuardServlet}.
     * 
     * @param errorResponseRenderer The error renderer to use in case of an OXException
     */
    public AbstractGuardServlet(GuardErrorResponseRenderer errorResponseRenderer) {
        this.errorResponseRenderer = errorResponseRenderer;
    }

    /**
     * Performs the an action requested by the "action" parameter in the given request if the action is an allowed action
     *
     * @param request the request containing the action parameter
     * @param response the response
     * @param allowedActions a set of allowed actions to perform
     */
    protected void doAction(HttpServletRequest request, HttpServletResponse response, HashMap<String, GuardServletAction> allowedActions) {
        String actionName = ServletUtils.getStringParameter(request, ACTION);
        GuardServletAction action = null;
        if (allowedActions != null && actionName != null) {
            action = allowedActions.get(actionName);
        }

        if (action != null) {
            doAction(request, response, actionName, action);
        } else {
            ServletUtils.sendError(response, "unknown action");
        }
    }

    /**
     * Performs the given action
     *
     * @param request request object
     * @param response response object
     * @param action the action to perform
     */
    protected void doAction(HttpServletRequest request, HttpServletResponse response, String actionName, GuardServletAction action) {
        try {
            action.doAction(request, response);
        } catch (OXApiException e) {
            //Passing the middleware exception on to the client
            LOG.error(String.format("OX API Error while processing command \"%s\": %s", actionName, e.getError()), e);
            ServletUtils.sendOK(response, e.getContentTypeHader().getValue(), e.getBackendErrorData());
        } catch (OXException e) {
            //Creating error object for the client
            LOG.error(String.format("Error processing command \"%s\": %s", actionName, e.getMessage()), e);
            try {
                errorResponseRenderer.renderError(request, response, actionName, e);
            } catch (IOException e1) {
                LOG.error(String.format("Error writing response: %s", e.getMessage()), e1);
                ServletUtils.sendError(response, e.getMessage());
            }
        } catch (Exception e) {
            //Unexpected exception
            LOG.error(String.format("Error processing command \"%s\": %s", actionName, e.getMessage()), e);
            ServletUtils.sendError(response, e.getMessage());
        } finally {
            GuardLogProperties.removeLogProperties();
        }
    }
}
